function plotdata=qqplot_wbounds(inputdata,alpha,plotyes)
% function plotdata=qqplot_wbounds(inputdata)
%
% Based on theory in
% https://www.stat.auckland.ac.nz/~ihaka/787/lectures-quantiles2-handouts.pdf
% and 
% http://www.mathematik.uni-kl.de/~schwaar/Exercises/Tabellen/table_kolmogorov.pdf
%
% wesleytk@ucla.edu, July 2015

if nargin<2
    plotyes=1;
    alpha=0.95;
end
if size(inputdata,2)>1
    error 'please load a single vector of data'
end

%% standardizing data if it hasn't been already
mu=mean(inputdata);
sd=std(inputdata);
sortdata=sort(inputdata,'ascend');
sortdata=(sortdata-mu)/sd; 

%% Get parameters of the reference distribution
n=length(inputdata);
if n<=35
    error 'only coded for large n'
end
k=sqrt(-0.5*log((1-alpha)/2))/sqrt(n);

Bounds=zeros(n,3); %Lower bound then upper bound
for dnd=1:n
    for bnd=1:3
        if bnd==3
            Bounds(dnd,bnd)=norminv(dnd/n,0,1);
            % Usual standard normal
        else
            Bounds(dnd,bnd)=norminv(dnd/n+k*(-1)^(bnd),0,1);
            % Norminv(Fn(x)-k) for LB, and Norminv(Fn(x)+k) for UB
        end
    end
end


if plotyes
    figure
    pl=plot(repmat(1:n,[3 1])',Bounds,'LineWidth',2,'color','red');
    set(gcf,'color','white');
    set(gca,'fontsize',18);
    xlabel('Quantal Level');
    ylabel('Standard Normal');
    set(pl(1),'DisplayName','Upper Bound');
    set(pl(2),'DisplayName','Lower Bound');
    set(pl(3),'DisplayName','Standard Normal');
    hold on
    sca=scatter(1:n,sortdata,'MarkerFaceColor',[0 0 0],'MarkerEdgeColor',[0 0 0],'Marker','.');
    hold off
end
plotdata.lowerbound=Bounds(:,1);
plotdata.upperbound=Bounds(:,2);
plotdata.medianstandard=Bounds(:,3);
plotdata.observeddata=sortdata;
